@@ -1,19 +1,30 @@
+from __future__ import annotations
+
 from concurrent.futures import Future
 from inspect import Signature
-from typing import Any, Callable, List, Tuple, Union
+from typing import Any, Callable, Generic, List, Optional, Sequence, TypeVar
 
-from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusSignature import (
+try:
+    from typing import ParamSpec
+except ImportError:
+    from typing_extensions import ParamSpec
+
+from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusDispatchSignature import (
     KiwoomOpenApiPlusDispatchSignature,
 )
+from koapy.compat.pyside2.QtAxContainer import QAxWidget
 from koapy.compat.pyside2.QtCore import QObject, Qt, Signal
 
+P = ParamSpec("P")
+R = TypeVar("R")
+
 
 class KiwoomOpenApiPlusDynamicCallableRunnable:
     def __init__(
         self,
         future: Future,
         fn: Callable[..., Any],
-        args: Union[Tuple[Any], List[Any]],
+        args: Sequence[Any],
     ):
         self._future = future
         self._fn = fn
@@ -24,10 +35,10 @@ class KiwoomOpenApiPlusDynamicCallableRunnable:
             return
         try:
             result = self._fn(self._args)
-        except BaseException as exc:
+        except BaseException as exc:  # pylint: disable=broad-except
             self._future.set_exception(exc)
             # break a reference cycle with the exception 'exc'
-            self = None
+            self = None  # pylint: disable=self-cls-assignment
         else:
             self._future.set_result(result)
 
@@ -35,11 +46,16 @@ class KiwoomOpenApiPlusDynamicCallableRunnable:
         return self._future.cancel()
 
 
-class KiwoomOpenApiPlusDynamicCallable(QObject):
+class KiwoomOpenApiPlusDynamicCallable(QObject, Generic[P, R]):
 
-    readyRunnable = Signal(KiwoomOpenApiPlusDynamicCallableRunnable)
+    ready_runnable = Signal(KiwoomOpenApiPlusDynamicCallableRunnable)
 
-    def __init__(self, control, name, parent=None):
+    def __init__(
+        self,
+        control: QAxWidget,
+        name: str,
+        parent: Optional[QObject] = None,
+    ):
         super().__init__(parent)
 
         self._control = control
@@ -51,13 +67,12 @@ class KiwoomOpenApiPlusDynamicCallable(QObject):
             self._signature.return_annotation is not Signature.empty
         )
 
-        self.readyRunnable.connect(self.onReadyRunnable, Qt.QueuedConnection)
-
-        self._call = self.call
+        self.ready_runnable.connect(self.on_ready_runnable, Qt.QueuedConnection)
 
         self.__name__ = self._name
+        self.__signature__ = self._signature
 
-    def bind_dynamic_call_args(self, *args, **kwargs):
+    def bind_dynamic_call_args(self, *args, **kwargs) -> List[Any]:
         try:
             ba = self._signature.bind(*args, **kwargs)
         except TypeError as e:
@@ -68,14 +83,14 @@ class KiwoomOpenApiPlusDynamicCallable(QObject):
         args = list(ba.args)
         return args
 
-    def is_valid_return_type(self, result):
-        if self._has_return_value and not isinstance(
-            result, self._signature.return_annotation
-        ):
-            return False
-        return True
+    def is_valid_return_type(self, result: Any) -> bool:
+        is_valid = True
+        if self._has_return_value:
+            if not isinstance(result, self._signature.return_annotation):
+                is_valid = False
+        return is_valid
 
-    def check_return_value(self, result):
+    def check_return_value(self, result: Any):
         if not self.is_valid_return_type(result):
             raise TypeError(
                 "Return type of %s was expected for function call %s(...), but %s was found"
@@ -87,30 +102,30 @@ class KiwoomOpenApiPlusDynamicCallable(QObject):
             )
         return result
 
-    def dynamic_call(self, args):
+    def dynamic_call(self, args: Sequence[Any]) -> R:
         return self._control.dynamicCall(self._function, args)
 
-    def dynamic_call_and_check(self, args):
+    def dynamic_call_and_check(self, args: Sequence[Any]) -> R:
         result = self.dynamic_call(args)
         self.check_return_value(result)
         return result
 
-    def call(self, *args, **kwargs):
+    def call(self, *args: P.args, **kwargs: P.kwargs) -> R:
         args = self.bind_dynamic_call_args(*args, **kwargs)
         result = self.dynamic_call_and_check(args)
         return result
 
-    def async_call(self, *args, **kwargs):
+    def async_call(self, *args: P.args, **kwargs: P.kwargs) -> Future:
         args = self.bind_dynamic_call_args(*args, **kwargs)
         future = Future()
         runnable = KiwoomOpenApiPlusDynamicCallableRunnable(
             future, self.dynamic_call_and_check, args
         )
-        self.readyRunnable.emit(runnable)
+        self.ready_runnable.emit(runnable)
         return future
 
-    def onReadyRunnable(self, runnable):
+    def on_ready_runnable(self, runnable: KiwoomOpenApiPlusDynamicCallableRunnable):
         runnable.run()
 
-    def __call__(self, *args, **kwargs):
-        return self._call(*args, **kwargs)
+    def __call__(self, *args: P.args, **kwargs: P.kwargs) -> R:
+        return self.call(*args, **kwargs)
