@@ -4,7 +4,7 @@ from pathlib import Path
 
 from deprecated import deprecated
 
-from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusTypeLib import (
+from koapy.backend.kiwoom_open_api_plus.core.KiwoomOpenApiPlusTypeLibSpec import (
     API_MODULE_PATH,
 )
 
