@@ -3,7 +3,7 @@ import click
 from .auto_login import auto_login
 
 
-@click.group(short_help="Disable many things.")
+@click.group(short_help="Disable things, including auto login.")
 def disable():
     pass
 
