@@ -1,19 +1,24 @@
-import datetime
 import logging
 
-logging.basicConfig(format='%(asctime)s [%(levelname)s] %(message)s - %(filename)s:%(lineno)d', level=logging.DEBUG)
+logging.basicConfig(
+    format="%(asctime)s [%(levelname)s] %(message)s - %(filename)s:%(lineno)d",
+    level=logging.DEBUG,
+)
+
+import datetime
 
-from koapy import KiwoomOpenApiPlusEntrypoint
 from exchange_calendars import get_calendar
 
-krx_calendar = get_calendar('XKRX')
+from koapy import KiwoomOpenApiPlusEntrypoint
+
+krx_calendar = get_calendar("XKRX")
 
 with KiwoomOpenApiPlusEntrypoint() as context:
     # 로그인 처리
     context.EnsureConnected()
 
     # 종목코드
-    code = '005930'
+    code = "005930"
 
     # 가장 최근 날짜
     start_date = datetime.datetime.now()
@@ -37,7 +42,7 @@ with KiwoomOpenApiPlusEntrypoint() as context:
     # 하지만 계산시 일반적인 휴일들을 제외한 임시공휴일, 선거일등은 별도 추가 데이터가 없는 한 반영되지 않으니 주의
 
     # 일봉 데이터
-    logging.info('Requesting daily data from %s to %s', end_date, start_date)
+    logging.info("Requesting daily data from %s to %s", end_date, start_date)
     data = context.GetDailyStockDataAsDataFrame(code, start_date, end_date)
     print(data)
 
@@ -45,21 +50,21 @@ with KiwoomOpenApiPlusEntrypoint() as context:
     # 분봉과 틱봉은 TR 에서 기준날짜 (기간설정시 최근날짜) 지정이 안되므로
     # 가장 최근부터 가져오고 클라이언트에서 따로 추가로 거르는 식으로 구현되어 있음
     end_date = start_date - 1 * krx_calendar.day
-    logging.info('Requesting minute data from %s to %s', end_date, start_date)
+    logging.info("Requesting minute data from %s to %s", end_date, start_date)
     data = context.GetMinuteStockDataAsDataFrame(code, 15, start_date, end_date)
     print(data)
 
     # 주봉 데이터
     # 참고로 주봉은 각 주의 첫 개장일을 기준일으로 함
     end_date = start_date - 30 * krx_calendar.day
-    logging.info('Requesting weekly data from %s to %s', end_date, start_date)
+    logging.info("Requesting weekly data from %s to %s", end_date, start_date)
     data = context.GetWeeklyStockDataAsDataFrame(code, start_date, end_date)
     print(data)
 
     # 월봉 데이터
     # 참고로 월봉은 각 달의 첫 개장일을 기준일으로 함
     end_date = start_date - 180 * krx_calendar.day
-    logging.info('Requesting monthly data from %s to %s', end_date, start_date)
+    logging.info("Requesting monthly data from %s to %s", end_date, start_date)
     data = context.GetMonthlyStockDataAsDataFrame(code, start_date, end_date)
     print(data)
 
@@ -67,6 +72,6 @@ with KiwoomOpenApiPlusEntrypoint() as context:
     # 분봉과 틱봉은 TR 에서 기준날짜 (기간설정시 최근날짜) 지정이 안되므로
     # 가장 최근부터 가져오고 클라이언트에서 따로 추가로 거르는 식으로 구현되어 있음
     end_date = start_date - 1 * krx_calendar.day
-    logging.info('Requesting tick data from %s to %s', end_date, start_date)
+    logging.info("Requesting tick data from %s to %s", end_date, start_date)
     data = context.GetTickStockDataAsDataFrame(code, 30, start_date, end_date)
     print(data)
