@@ -101,28 +101,52 @@ def run_as_admin(cmd, cwd=None, check=True, wait=True):
     return rc
 
 
+def create_job_object_for_cleanup():
+    # https://stackoverflow.com/questions/23434842/python-how-to-kill-child-processes-when-parent-dies/23587108#23587108s
+    import win32job
+
+    jobAttributes = None
+    jobName = ""
+    hJob = win32job.CreateJobObject(jobAttributes, jobName)
+    extendedInfo = win32job.QueryInformationJobObject(
+        hJob, win32job.JobObjectExtendedLimitInformation
+    )
+    basicLimitInformation = extendedInfo["BasicLimitInformation"]
+    basicLimitInformation["LimitFlags"] = win32job.JOB_OBJECT_LIMIT_KILL_ON_JOB_CLOSE
+    win32job.SetInformationJobObject(
+        hJob,
+        win32job.JobObjectExtendedLimitInformation,
+        extendedInfo,
+    )
+    return hJob
+
+
+job_handle = create_job_object_for_cleanup()
+
+
+def make_process_die_when_parent_dies(pid):
+    assert pid != 0
+
+    # https://stackoverflow.com/questions/23434842/python-how-to-kill-child-processes-when-parent-dies/23587108#23587108s
+    import win32api
+    import win32con
+    import win32job
+
+    desiredAccess = win32con.PROCESS_TERMINATE | win32con.PROCESS_SET_QUOTA
+    inheritHandle = False
+    hProcess = win32api.OpenProcess(
+        desiredAccess,
+        inheritHandle,
+        pid,
+    )
+    # process will be terminated when job is destroyed
+    # job will be destroyed when its last handle is closed
+    # job handle will be closed when it loses its reference, hJob in this case
+    hJob = job_handle
+    win32job.AssignProcessToJobObject(hJob, hProcess)
+
+
 class Popen(subprocess.Popen):
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-
-        # https://stackoverflow.com/questions/23434842/python-how-to-kill-child-processes-when-parent-dies/23587108#23587108s
-        import win32api
-        import win32con
-        import win32job
-
-        hJob = win32job.CreateJobObject(None, "")
-        extendedInfo = win32job.QueryInformationJobObject(
-            hJob, win32job.JobObjectExtendedLimitInformation
-        )
-        extendedInfo["BasicLimitInformation"][
-            "LimitFlags"
-        ] = win32job.JOB_OBJECT_LIMIT_KILL_ON_JOB_CLOSE
-        win32job.SetInformationJobObject(
-            hJob, win32job.JobObjectExtendedLimitInformation, extendedInfo
-        )
-        perms = win32con.PROCESS_TERMINATE | win32con.PROCESS_SET_QUOTA
-        hProcess = win32api.OpenProcess(perms, False, self.pid)
-        win32job.AssignProcessToJobObject(hJob, hProcess)
-
-        self._hJob = hJob
-        self._hProcess = hProcess
+        make_process_die_when_parent_dies(self.pid)
